==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/TreemapNodePointerEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TreemapNodePointerEventArgsDescription } from "./TreemapNodePointerEventArgsDescription";
/**
 * @hidden
 */
export let TreemapNodePointerEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class TreemapNodePointerEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (TreemapNodePointerEventArgsDescriptionMetadata.a == null) {
                TreemapNodePointerEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TreemapNodePointerEventArgsDescriptionMetadata.c(TreemapNodePointerEventArgsDescriptionMetadata.a);
            }
            if (a.k(TreemapNodePointerEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(TreemapNodePointerEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Value", "Number:double");
            a.item("Sum", "Number:double");
            a.item("CustomValueRef", "(w:CustomValue,wf:CustomValue)DataRef");
            a.item("ItemRef", "(w:Item,wf:Item)DataRef");
            a.item("ParentItemRef", "(w:ParentItem,wf:ParentItem)DataRef");
            a.item("Position", "Point");
            a.item("IsRightButton", "Boolean");
            a.item("IsHandled", "Boolean");
            a.item("IsOverHeader", "Boolean");
            a.item("Label", "String");
            a.item("ParentValue", "Number:double");
            a.item("ParentLabel", "String");
            a.item("ParentSum", "Number:double");
        }
        static d(a) {
            TreemapNodePointerEventArgsDescriptionMetadata.b(a);
            a.ad("TreemapNodePointerEventArgs", () => new TreemapNodePointerEventArgsDescription());
            a.ac("TreemapNodePointerEventArgs", TreemapNodePointerEventArgsDescriptionMetadata.a);
        }
    }
    TreemapNodePointerEventArgsDescriptionMetadata.$t = markType(TreemapNodePointerEventArgsDescriptionMetadata, 'TreemapNodePointerEventArgsDescriptionMetadata');
    TreemapNodePointerEventArgsDescriptionMetadata.a = null;
    return TreemapNodePointerEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/TreemapNodePointerEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TreemapNodePointerEventArgsDescription } from "./TreemapNodePointerEventArgsDescription";
/**
 * @hidden
 */
export let TreemapNodePointerEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class TreemapNodePointerEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (TreemapNodePointerEventArgsDescriptionMetadata.a == null) {
                TreemapNodePointerEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TreemapNodePointerEventArgsDescriptionMetadata.c(TreemapNodePointerEventArgsDescriptionMetadata.a);
            }
            if (a.k(TreemapNodePointerEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(TreemapNodePointerEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Value", "Number:double");
            a.item("Sum", "Number:double");
            a.item("CustomValueRef", "(w:CustomValue,wf:CustomValue)DataRef");
            a.item("ItemRef", "(w:Item,wf:Item)DataRef");
            a.item("ParentItemRef", "(w:ParentItem,wf:ParentItem)DataRef");
            a.item("Position", "Point");
            a.item("IsRightButton", "Boolean");
            a.item("IsHandled", "Boolean");
            a.item("IsOverHeader", "Boolean");
            a.item("Label", "String");
            a.item("ParentValue", "Number:double");
            a.item("ParentLabel", "String");
            a.item("ParentSum", "Number:double");
        }
        static d(a) {
            TreemapNodePointerEventArgsDescriptionMetadata.b(a);
            a.ae("TreemapNodePointerEventArgs", () => new TreemapNodePointerEventArgsDescription());
            a.ad("TreemapNodePointerEventArgs", TreemapNodePointerEventArgsDescriptionMetadata.a);
        }
    }
    TreemapNodePointerEventArgsDescriptionMetadata.$t = markType(TreemapNodePointerEventArgsDescriptionMetadata, 'TreemapNodePointerEventArgsDescriptionMetadata');
    TreemapNodePointerEventArgsDescriptionMetadata.a = null;
    return TreemapNodePointerEventArgsDescriptionMetadata;
})();
